@@ -72,17 +72,6 @@ VPC_DEFAULT_SUBNETS_CIDR_BLOCK_PUBLIC = [
     f"{VPC_DEFAULT_CIDR_BLOCK_PREFIX}.{i + 200}.0/24" for i in range(AZones["MAX"])
 ]
 
-PARAMETERS_SKIP_OVERRIDE_CONDITION = (
-    "Env",
-    "UpdateMode",
-    "RecordSetExternal",
-    "DoNotSignal",
-    "EfsMounts",
-    "LaunchTemplateDataImageIdLatest",
-    "VPCCidrBlock",
-    "VPCName",
-)
-
 TROPO_CLASS_TO_CFM = {
     "AWS::WAFv2::WebACL": {
         "WebACLRule": "Rule",
@@ -279,11 +268,6 @@ CFG_TO_FUNC = {
     "Parameter": {"module": "cloudformation", "func": "CFM_Parameters"},
     "Condition": {"module": "cloudformation", "func": "CFM_Conditions"},
     "Mapping": {"module": "cloudformation", "func": "CFM_Mappings"},
-    "Alarm": {
-        "module": "joker",
-        "func": ("cloudwatch", "Alarm"),
-        "dep": ["LoadBalancer", "SQSQueue"],
-    },
     "ApiGatewayAccount": {"module": "joker", "func": ("apigateway", "Account")},
     "ApiGatewayApiKey": {"module": "joker", "func": ("apigateway", "ApiKey")},
     "ApiGatewayBasePathMapping": {
@@ -305,26 +289,52 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("apigateway", "UsagePlanKey"),
     },
+    "ApplicationAutoScalingScalableTarget": {
+        "module": "joker",
+        "func": ("applicationautoscaling", "ScalableTarget"),
+    },
     "ApplicationAutoScalingScalingPolicy": {
-        "module": "autoscaling",
-        "func": "AS_ScalingPolicies",
+        "module": "joker",
+        "func": ("applicationautoscaling", "ScalingPolicy"),
+    },
+    "AutoScalingLifecycleHook": {
+        "module": "joker",
+        "func": ("autoscaling", "LifecycleHook"),
     },
-    "Apps": {"module": "joker", "func": ("codedeploy", "DeploymentGroup")},
-    "ASGLifecycleHook": {"module": "joker", "func": ("autoscaling", "LifecycleHook")},
     "AutoScalingGroup": {
         "module": "autoscaling",
         "func": "AS_Autoscaling",
         "dep": ["SecurityGroups"],
     },
-    "AutoScalingScalingPolicy": {"module": "autoscaling", "func": "AS_ScalingPolicies"},
-    "Bucket": {"module": "s3", "func": "S3_Buckets"},
-    "Certificate": {"module": "joker", "func": ("certificatemanager", "Certificate")},
-    "CacheSubnetGroup": {"module": "joker", "func": ("elasticache", "SubnetGroup")},
+    "AutoScalingScalingPolicy": {
+        "module": "joker",
+        "func": ("autoscaling", "ScalingPolicy"),
+    },
+    "AutoScalingScheduledAction": {
+        "module": "joker",
+        "func": ("autoscaling", "ScheduledAction"),
+    },
+    "CertificateManagerCertificate": {
+        "module": "joker",
+        "func": ("certificatemanager", "Certificate"),
+    },
+    "CloudFormationCustomResource": {
+        "module": "joker",
+        "func": ("cloudformation", "CustomResource"),
+    },
     "CloudFrontCachePolicy": {"module": "joker", "func": ("cloudfront", "CachePolicy")},
     "CloudFrontDistribution": {
         "module": "cloudfront",
         "func": "CF_CloudFront",
-        "dep": ["LoadBalancer", "CloudFrontLambdaFunctionAssociation"],
+        "dep": [
+            "ElasticLoadBalancingV2Listener",
+            "LoadBalancer",
+            "CloudFrontLambdaFunctionAssociation",
+        ],
+    },
+    "CloudFrontFunction": {
+        "module": "joker",
+        "func": ("cloudfront", "Function"),
     },
     "CloudFrontLambdaFunctionAssociation": {
         "module": "joker",
@@ -333,7 +343,7 @@ CFG_TO_FUNC = {
     "CloudFrontOriginAccessIdentity": {
         "module": "joker",
         "func": ("cloudfront", "CloudFrontOriginAccessIdentity"),
-        "dep": ["Bucket"],
+        "dep": ["S3Bucket"],
     },
     "CloudFrontOriginRequestPolicy": {
         "module": "joker",
@@ -343,13 +353,32 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("cloudfront", "ResponseHeadersPolicy"),
     },
-    "CodeDeployApp": {"module": "joker", "func": ("codedeploy", "Application")},
+    "CloudWatchAlarm": {
+        "module": "joker",
+        "func": ("cloudwatch", "Alarm"),
+        "dep": ["LoadBalancer", "SQSQueue"],
+    },
+    "CodeDeployApplication": {"module": "joker", "func": ("codedeploy", "Application")},
+    "CodeDeployDeploymentGroup": {
+        "module": "joker",
+        "func": ("codedeploy", "DeploymentGroup"),
+    },
     "DynamoDBTable": {"module": "joker", "func": ("dynamodb", "Table")},
     "EC2EIP": {"module": "joker", "func": ("ec2", "EIP")},
     "EC2InternetGateway": {"module": "joker", "func": ("ec2", "InternetGateway")},
     "EC2NatGateway": {"module": "joker", "func": ("ec2", "NatGateway")},
     "EC2Route": {"module": "joker", "func": ("ec2", "Route")},
     "EC2RouteTable": {"module": "joker", "func": ("ec2", "RouteTable")},
+    "EC2SecurityGroup": {
+        "module": "ec2",
+        "func": "SG_SecurityGroup",
+        "dep": ["ECSTaskDefinition"],
+    },
+    "EC2SecurityGroupIngress": {
+        "module": "ec2",
+        "func": "SG_SecurityGroupIngresses",
+        "dep": ["ElasticLoadBalancingV2Listener"],
+    },
     "EC2Subnet": {"module": "ec2", "func": "EC2_Subnet"},
     "EC2VPC": {"module": "joker", "func": ("ec2", "VPC")},
     "EC2VPCEndpoint": {"module": "joker", "func": ("ec2", "VPCEndpoint")},
@@ -368,6 +397,12 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("ecs", "ClusterCapacityProviderAssociations"),
     },
+    "ECSService": {
+        "module": "joker",
+        "func": ("ecs", "Service"),
+        "dep": ["SecurityGroups"],
+    },
+    "ECSTaskDefinition": {"module": "ecs", "func": "ECS_TaskDefinition"},
     "EFSAccessPoint": {"module": "joker", "func": ("efs", "AccessPoint")},
     "EFSFileSystem": {"module": "efs", "func": "EFS_FileStorage"},
     "ElastiCacheCacheCluster": {
@@ -378,6 +413,19 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("elasticache", "ReplicationGroup"),
     },
+    "ElastiCacheSubnetGroup": {
+        "module": "joker",
+        "func": ("elasticache", "SubnetGroup"),
+    },
+    "ElasticLoadBalancingV2LoadBalancer": {
+        "module": "joker",
+        "func": ("elasticloadbalancingv2", "LoadBalancer"),
+    },
+    "ElasticLoadBalancingV2Listener": {
+        "module": "joker",
+        "func": ("elasticloadbalancingv2", "Listener"),
+        "dep": ["LoadBalancer"],
+    },
     "ElasticLoadBalancingV2ListenerRule": {
         "module": "joker",
         "func": ("elasticloadbalancingv2", "ListenerRule"),
@@ -385,20 +433,26 @@ CFG_TO_FUNC = {
     "ElasticLoadBalancingV2TargetGroup": {
         "module": "joker",
         "func": ("elasticloadbalancingv2", "TargetGroup"),
+        # need this for override on ContainerDefinitions1ContainerPort
+        "dep": ["ECSTaskDefinition"],
     },
     "EventsRule": {
-        "module": "events",
-        "func": "EVE_EventRules",
+        "module": "joker",
+        "func": ("events", "Rule"),
         "dep": ["SecurityGroups"],
     },
     "IAMGroup": {"module": "iam", "func": "IAM_Groups"},
     "IAMInstanceProfile": {"module": "joker", "func": ("iam", "InstanceProfile")},
     "IAMManagedPolicy": {"module": "joker", "func": ("iam", "ManagedPolicy")},
-    "IAMPolicy": {"module": "joker", "func": ("iam", "PolicyType"), "dep": ["Bucket"]},
+    "IAMPolicy": {
+        "module": "joker",
+        "func": ("iam", "PolicyType"),
+        "dep": ["S3Bucket"],
+    },
     "IAMRole": {
         "module": "joker",
         "func": ("iam", "Role"),
-        "dep": ["Lambda", "Bucket"],
+        "dep": ["Lambda", "S3Bucket"],
     },
     "IAMUser": {"module": "iam", "func": "IAM_Users"},
     "IAMUserToGroupAddition": {"module": "iam", "func": "IAM_UserToGroupAdditions"},
@@ -422,7 +476,7 @@ CFG_TO_FUNC = {
     "LambdaPermission": {
         "module": "joker",
         "func": ("awslambda", "Permission"),
-        "dep": ["SNSSubscription", "Lambda", "EventsRule"],
+        "dep": ["SNSSubscription", "Lambda", "EventsRule", "SchedulerSchedule"],
     },
     "LambdaVersion": {
         "module": "joker",
@@ -438,18 +492,19 @@ CFG_TO_FUNC = {
         "func": ("logs", "LogGroup"),
         "dep": ["Lambda"],
     },
-    "ScheduledAction": {"module": "joker", "func": ("autoscaling", "ScheduledAction")},
-    "ScalableTarget": {
-        "module": "joker",
-        "func": ("applicationautoscaling", "ScalableTarget"),
-    },
     "RDSDBInstance": {"module": "rds", "func": "RDS_DB"},
     "RDSDBSubnetGroup": {"module": "joker", "func": ("rds", "DBSubnetGroup")},
     "Route53HostedZone": {"module": "joker", "func": ("route53", "HostedZone")},
     "Route53RecordSet": {
         "module": "joker",
         "func": ("route53", "RecordSetType"),
-        "dep": ["ApiGatewayDomainName", "DBInstance", "EFSFileSystem", "LoadBalancer"],
+        "dep": [
+            "ApiGatewayDomainName",
+            "DBInstance",
+            "EFSFileSystem",
+            "LoadBalancer",
+            "CloudFrontDistribution",
+        ],
     },
     "Route53ResolverEndpoint": {
         "module": "joker",
@@ -463,16 +518,11 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("route53resolver", "ResolverRuleAssociation"),
     },
-    "SecurityGroup": {"module": "ec2", "func": "SG_SecurityGroup"},
-    "SecurityGroupIngress": {
+    "S3Bucket": {"module": "s3", "func": "S3_Buckets"},
+    "SecurityGroups": {
         "module": "ec2",
-        "func": "SG_SecurityGroupIngresses",
-    },
-    "SecurityGroups": {"module": "ec2", "func": "SG_SecurityGroups"},
-    "Service": {
-        "module": "ecs",
-        "func": "ECS_Service",
-        "dep": ["SecurityGroups"],
+        "func": "SG_SecurityGroups",
+        "dep": ["LoadBalancer"],
     },
     "ServiceDiscoveryPublicDnsNamespace": {
         "module": "joker",
@@ -482,6 +532,11 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("servicediscovery", "Service"),
     },
+    "SchedulerSchedule": {
+        "module": "joker",
+        "func": ("scheduler", "Schedule"),
+        "dep": ["SecurityGroups"],
+    },
     "SQSQueue": {"module": "joker", "func": ("sqs", "Queue")},
     "SQSQueuePolicy": {
         "module": "joker",
@@ -491,7 +546,6 @@ CFG_TO_FUNC = {
     "SNSSubscription": {"module": "joker", "func": ("sns", "SubscriptionResource")},
     "SNSTopic": {"module": "joker", "func": ("sns", "Topic")},
     "SSMParameter": {"module": "joker", "func": ("ssm", "Parameter")},
-    "TaskDefinition": {"module": "ecs", "func": "ECS_TaskDefinition"},
     "WafByteMatchSet": {
         "module": "waf",
         "func": ["WAF_GlobalByteMatchSets", "WAF_RegionalByteMatchSets"],
@@ -510,15 +564,6 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("wafv2", "WebACL"),
     },
-    # CloudformationCustomResource begin here
-    "CCRFargateSpot": {
-        "module": "cloudformation",
-        "func": "CFM_CustomResourceFargateSpot",
-    },
-    "CCRLightHouse": {
-        "module": "cloudformation",
-        "func": "CFM_CustomResourceLightHouse",
-    },
     # ReplicateRegions need to be the last one
     "CCRReplicateRegions": {
         "module": "cloudformation",
