@@ -12,6 +12,7 @@ IBOX_SPECIAL_KEYS = (
     "IBOX_PROPNAME",
     "IBOX_CURNAME",
     "IBOX_REFNAME",
+    "IBOX_TITLE",
     "IBOX_LINKED_OBJ_NAME",
     "IBOX_LINKED_OBJ_INDEX",
     "IBOX_LINKED_OBJ_FOR",
@@ -36,11 +37,11 @@ class Parameter(Parameter):
         if title.startswith("EnvApp") and title.endswith("Version"):
             add_obj(
                 [
-                    get_condition(title, "not_equals", "", nomap=True),
+                    # get_condition(title, "not_equals", "", nomap=True),
                     ssm.Parameter(
                         f"SSMParameter{title}",
                         Type="String",
-                        Condition=title,
+                        # Condition=title,
                         Name=Sub(
                             "/EnvAppVersions/${EnvRole}/${AWS::StackName}/%s" % title
                         ),
@@ -53,8 +54,7 @@ class Parameter(Parameter):
 def stack_add_res():
     for n, v in cfg.Parameters.items():
         # Automatically create override conditions for parameters
-        if not n.startswith(PARAMETERS_SKIP_OVERRIDE_CONDITION):
-
+        if n in list(cfg.fixedvalues) + cfg.mappedvalues:
             if n.endswith("InstanceType"):
                 default = "default"
             elif n == "SecurityGroups":
@@ -150,11 +150,12 @@ def add_objoutput(res):
                 condition = res.Condition
             except Exception:
                 try:
-                    cond = iboxprops[f"{mapname}Condition"][0].Condition
+                    # look for condition on current-resource
+                    res.Condition = iboxprops[f"{mapname}Condition"][0].Condition
                 except Exception:
-                    pass
-                else:
-                    res.Condition = cond
+                    # look for condition on root-resource
+                    if hasattr(iboxprops["OBJ"], "Condition"):
+                        res.Condition = iboxprops["OBJ"].Condition
             else:
                 # Use a fake Condition wih value None in cfg to avoid creating a condition
                 if condition == "None":
@@ -183,6 +184,7 @@ def get_endvalue(
     fixedvalues=None,
     mapinlist=False,
     no_check_for_mappedvalues=False,
+    add_override=True,
 ):
     if not fixedvalues:
         # set default if not defined
@@ -193,8 +195,9 @@ def get_endvalue(
             param = condname
         if (
             cfg.no_override is False
+            and add_override
             and param in cfg.Parameters
-            and not param.startswith(PARAMETERS_SKIP_OVERRIDE_CONDITION)
+            and param in list(cfg.fixedvalues) + cfg.mappedvalues
         ):
             override_value = If(f"{param}Override", Ref(param), value)
         else:
@@ -222,6 +225,9 @@ def get_endvalue(
         # ... otherway use mapping
         elif no_check_for_mappedvalues or param in cfg.mappedvalues:
             value = FindInMap(Ref("EnvShort"), Ref("AWS::Region"), param)
+        # .. or return relative paramter
+        elif param in cfg.Parameters:
+            return Ref(param)
         else:
             raise ValueError(f"{param} not present in mappedvalues.")
 
@@ -428,7 +434,7 @@ def get_condition(
 
     if (
         key_name in cfg.Parameters
-        and not key_name.startswith(PARAMETERS_SKIP_OVERRIDE_CONDITION)
+        and key_name in list(cfg.fixedvalues) + cfg.mappedvalues
         and not nomap
     ):
         key_override = f"{key_name}Override"
@@ -457,27 +463,33 @@ def get_condition(
 
 def import_user_data(name):
     TK_IN_UDATA = "_IBOX_CODE_"
+    parent_dir_name = os.path.dirname(os.path.realpath(__file__))
+
+    udata_file_main = os.path.join(parent_dir_name, f"user-data/{name}.sh")
+    udata_file_ext = os.path.join(os.getcwd(), f"lib/user-data/{name}.sh")
+
+    if os.path.basename(name).islower() and os.path.exists(udata_file_ext):
+        # for envrole external script
+        udata_file = udata_file_ext
+    else:
+        udata_file = udata_file_main
 
-    udata_file = os.path.join(os.getcwd(), f"lib/user-data/{name}.sh")
     if not os.path.exists(udata_file):
-        parent_dir_name = os.path.dirname(os.path.realpath(__file__))
-        udata_file = os.path.join(parent_dir_name, f"user-data/{name}.sh")
+        return []
 
     try:
         with open(udata_file, "r") as f:
-            fdata = f.read()
-            code = fdata
-            code_lines = code.splitlines(keepends=True)
+            code_lines = f.read().splitlines(keepends=True)
 
             file_lines = []
-            # parse lambda code for Token IBOX CODE
+            # parse code for Token IBOX CODE
             for x in code_lines:
                 if x.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
                     value = eval(x)
                 elif x.startswith(TK_IN_UDATA):
                     value = '"'
                 elif TK_IN_UDATA in x:
-                    # parse minified code
+                    # parse Token in string
                     tks = x.split(TK_IN_UDATA)
                     file_lines.extend([f"{tks[0]}", eval(tks[1]), tks[2]])
                     continue
@@ -491,7 +503,7 @@ def import_user_data(name):
     except IOError:
         raise
     except Exception as e:
-        logging.error(f"Error importing user-data: {e}")
+        logging.error(f"Error importing user-data {name}: {e}")
         exit(1)
 
 
@@ -582,14 +594,15 @@ def auto_get_props(
     # with the name equals to the mapname and the relative value.
     # Later i will assign this dict to the relative output object using
     # IBOX_OUTPUT
-    IBOX_PROPS = {"MAP": {}}
+    if not "IBOX_PROPS" in globals():
+        IBOX_PROPS = {"MAP": {}, "OBJ": obj}
 
     res_obj_type = getattr(obj, "resource_type", res_obj_type)
 
     def _get_obj(obj, key, obj_propname, mapname):
         props = obj.props
         mapname_obj = f"{mapname}{obj_propname}"
-        global IBOX_PROPNAME
+        global IBOX_PROPNAME, IBOX_REFNAME
 
         def _get_obj_tags():
             prop_list = []
@@ -716,6 +729,10 @@ def auto_get_props(
             prop_list = []
             prop_class = prop_class[0]
 
+            # save IBOX_REFNAME
+            if "IBOX_REFNAME" in globals():
+                globals()[f"IBOX_REFNAME@{mapname}"] = globals()["IBOX_REFNAME"]
+
             for o, v in key[obj_propname].items():
                 # for a list of properties set IBOX_PROPNAME to the name of property
                 IBOX_PROPNAME = o
@@ -738,6 +755,10 @@ def auto_get_props(
                 else:
                     prop_list.append(iboxif(if_wrapper, mapname, prop_obj))
 
+            # restore IBOX_REFNAME
+            if f"IBOX_REFNAME@{mapname}" in globals():
+                IBOX_REFNAME = globals()[f"IBOX_REFNAME@{mapname}"]
+
             if prop_list:
                 return prop_list
 
@@ -753,7 +774,7 @@ def auto_get_props(
             return get_dictvalue(key[obj_propname])
 
     def _populate(obj, key=None, mapname=None, rootdict=None):
-        global IBOX_RESNAME, IBOX_CURNAME, IBOX_REFNAME
+        global IBOX_RESNAME, IBOX_CURNAME, IBOX_REFNAME, IBOX_TITLE
 
         if not mapname:
             mapname = obj.title
@@ -763,9 +784,14 @@ def auto_get_props(
         if not key:
             key = getattr(cfg, mapname)
 
+        if key.get("IBOX_TITLE"):
+            IBOX_TITLE = parse_ibox_key(key["IBOX_TITLE"])
+
         def _try_PCO_in_obj(key):
             def _parameter(k):
                 for n, v in k.items():
+                    if not eval(v.get("IBOX_ENABLED_IF", "True")):
+                        continue
                     n = parse_ibox_key(n)
                     parameter = Parameter(n)
                     _populate(parameter, rootdict=v)
@@ -807,25 +833,31 @@ def auto_get_props(
                     func_map[pco](k)
 
         def _auto_PO(name, conf, mode, value=""):
-            if mode == "p":
+            conf = dict(conf)
+            if "p" in mode:
                 parameter_base = {"Description": "Empty for mapped value"}
                 parameter_base.update(conf)
+                # avoid including Output Condition in Parameter
+                parameter_base.pop("Condition", "")
                 pco_conf = {"IBOX_PARAMETER": {f"{mapname}{name}": parameter_base}}
-                # look for Condition key and if found update pco_conf
-                condition = conf.get("Condition")
+                # look for CONDITION key and if found update pco_conf
+                condition = conf.get("CONDITION")
                 if condition:
-                    pco_conf.update(
-                        {"IBOX_CONDITION": {f"{mapname}{name}": condition}}
-                    )
+                    pco_conf.update({"IBOX_CONDITION": {f"{mapname}{name}": condition}})
                 _try_PCO_in_obj(pco_conf)
-            if mode == "o":
+            if "o" in mode:
+                # avoid parsing Parameter Descrption as output one
+                conf.pop("Description", "")
                 if isinstance(value, int):
                     # Output value must be a string
                     value = str(value)
+                elif isinstance(value, str) and value.startswith("get_endvalue"):
+                    value = eval(value)
                 output_base = {"Value": value}
                 output_base.update(conf)
-                output = {"IBOX_OUTPUT": {f"{mapname}{name}": output_base}}
-                _try_PCO_in_obj(output)
+                if output_base["Value"] != "IBOX_SKIP":
+                    output = {"IBOX_OUTPUT": {f"{mapname}{name}": output_base}}
+                    _try_PCO_in_obj(output)
 
         def _process_ibox_auto_pco_key(propname):
             ibox_auto_p = f"{propname}.IBOX_AUTO_P"
@@ -844,6 +876,8 @@ def auto_get_props(
                 _try_PCO_in_obj(key[ibox_pco])
 
         def _proc_custom_obj(base_rootdict, key_value, mapname, propname):
+            global IBOX_RESNAME, IBOX_MAPNAME
+
             values = []
             if not base_rootdict:
                 base_rootdict = getattr(cfg, f"{mapname}IBOX_CUSTOM_OBJ{propname}")
@@ -863,7 +897,19 @@ def auto_get_props(
                     obj_title = f"{n}Value"
                 rootdict.update(base_rootdict)
                 obj = IBOX_Custom_Obj(obj_title)
-                auto_get_props(obj, rootdict=rootdict, mapname=f"{mapname}{propname}")
+
+                # save IBOX_RESNAME and IBOX_MAPNAME
+                IBOX_RESNAME_SAVE = IBOX_RESNAME
+                IBOX_MAPNAME_SAVE = IBOX_MAPNAME
+                # set IBOX_RESNAME and IBOX_MAPNAME to call _populate like auto_get_props
+                IBOX_RESNAME = obj_title
+                IBOX_MAPNAME = f"{mapname}{propname}"
+                # populate OBJ
+                _populate(obj, rootdict=rootdict, mapname=IBOX_MAPNAME)
+                # restore IBOX_RESNAME and IBOX_MAPNAME
+                IBOX_RESNAME = IBOX_RESNAME_SAVE
+                IBOX_MAPNAME = IBOX_MAPNAME_SAVE
+
                 value = getattr(obj, "Value")
                 if v == "IBOX_IFCONDVALUE":
                     condname = f"{mapname}{propname}{n}"
@@ -962,6 +1008,11 @@ def auto_get_props(
             list(key.items()) + list(dict.fromkeys(props, None).items())
         ).keys():
             if key.get(propname) == "IBOX_SKIP":
+                # remove existing property if exist
+                try:
+                    del obj.properties[propname]
+                except Exception:
+                    pass
                 continue
 
             # IBOX KEY TO LOOK FOR
@@ -971,20 +1022,36 @@ def auto_get_props(
             ibox_code = f"{propname}.IBOX_CODE"
             ibox_code_key = f"{propname}.IBOX_CODE_KEY"
             ibox_custom_obj = f"{propname}.IBOX_CUSTOM_OBJ"
+            ibox_propname_fixed = f"{propname}@"
+
+            # need to make work @ override even if propname is not in mapped values
+            if ibox_propname_fixed in key and propname not in cfg.mappedvalues:
+                key[propname] = key[ibox_propname_fixed]
+                cfg.fixedvalues[f"{mapname}{propname}"] = key[propname]
+
+            custom_key_only = propname.replace(".IBOX_AUTO_PO", "")
 
             if not isinstance(obj, (Output, Parameter, Condition)):
                 IBOX_CURNAME = f"{mapname}{propname}"
 
-            # IBOX_PCO for Custom Key ONLY
-            # process ibox_pco for custom key not present in obj props
-            # but only if there is not a relative ibox_auto_p/o or ibox_code key
+            # IBOX_PCO and IBOX_AUTO_PO for Custom Key ONLY
             if (
                 ibox_pco in key
                 and propname in key
                 and propname not in props
                 and all(n not in key for n in [ibox_auto_p, ibox_auto_po, ibox_code])
             ):
+                # process ibox_pco for custom key not present in obj props
+                # but only if there is not a relative ibox_auto_p/o or ibox_code key
                 _try_PCO_in_obj(key[ibox_pco])
+            elif propname.endswith("IBOX_AUTO_PO") and custom_key_only not in props:
+                # process IBOX_AUTO_PO custom key if the relative propname do not exist in resource props
+                _auto_PO(
+                    custom_key_only,
+                    key[propname],
+                    "po",
+                    f"get_endvalue('{mapname}{custom_key_only}')",
+                )
 
             # IBOX_CODE
             if ibox_code in key and propname in props:
@@ -992,10 +1059,10 @@ def auto_get_props(
                 # First process IBOX_AUTO_PO and IBOX_PCO keys
                 _process_ibox_auto_pco_key(propname)
                 value = eval(key[ibox_code])
-            elif (
-                propname in key
-                and propname in props
-                or (propname in key and ibox_custom_obj in key)
+            elif propname in key and (
+                propname in props
+                or ibox_custom_obj in key
+                or res_obj_type == "AWS::CloudFormation::CustomResource"
             ):
                 # there is match between obj prop and a dict key or there is a custom obj
                 key_value = key[propname]
@@ -1009,12 +1076,9 @@ def auto_get_props(
                 # set value
                 elif isinstance(key_value, (list, dict)) and ibox_custom_obj in key:
                     # to process a list like a custom obj
-                    save_ibox_resname = IBOX_RESNAME
                     value = _proc_custom_obj(
                         key[ibox_custom_obj], key_value, mapname, propname
                     )
-                    # need to save and restore IBOX_RESNAME because during processing _proc_custom_obj it change
-                    IBOX_RESNAME = save_ibox_resname
                 elif isinstance(key_value, dict):
                     # key value is a dict, get populated object
                     value = _get_obj(obj, key, propname, mapname)
@@ -1078,9 +1142,6 @@ def auto_get_props(
                 # Automatically create output
                 if ibox_auto_po in key:
                     ibox_auto_po_value = key[ibox_auto_po]
-                    if "Description" in ibox_auto_po_value:
-                        # avoid parsing Parameter Descrption as output one
-                        del ibox_auto_po_value["Description"]
                     _auto_PO(propname, ibox_auto_po_value, "o", value)
 
         # need to redefine it here because it's has been changed by nested supprop
